@@ -5,7 +5,6 @@ from jaseci.api.interface import Interface
 from jaseci.actor.walker import Walker
 from jaseci.graph.node import Node
 from jaseci.actor.sentinel import Sentinel
-from jaseci.utils.utils import b64decode_str
 from jaseci.utils.id_list import IdList
 
 
@@ -24,30 +23,6 @@ class WalkerApi:
         self.spawned_walker_ids = IdList(self)
         self.yielded_walkers_ids = IdList(self)
 
-    @Interface.private_api(cli_args=["code"])
-    def walker_register(
-        self,
-        snt: Sentinel = None,
-        code: str = "",
-        dir: str = "/",
-        encoded: bool = False,
-    ):
-        """
-        Allows for the specific parsing and registering of individual walkers.
-
-        Though the common case is to register entire sentinels, a user can also
-        register individual walkers one at a time. This API accepts code for a single
-        walker (i.e., \\lstinline\\{walker \\{...\\}\\}).
-        """
-        if encoded:
-            code = b64decode_str(code)
-        walk = snt.register_walker(code, dir)
-        if walk:
-            self.extract_arch_aliases(snt, walk)
-            return walk.serialize()
-        else:
-            return ["Walker not created, invalid code!"]
-
     @Interface.private_api(cli_args=["wlk"])
     def walker_get(self, wlk: Walker, mode: str = "default", detailed: bool = False):
         """
@@ -63,23 +38,6 @@ class WalkerApi:
         else:
             return wlk.serialize(detailed=detailed)
 
-    @Interface.private_api(cli_args=["wlk"])
-    def walker_set(self, wlk: Walker, code: str, mode: str = "default"):
-        """
-        Set code/ir for a walker
-        Valid modes: {code, ir, }
-        """
-        if mode == "code" or mode == "default":
-            wlk.register(code)
-        elif mode == "ir":
-            wlk.apply_ir(code)
-        else:
-            return [f"Invalid mode to set {wlk}"]
-        if wlk.is_active:
-            return [f"{wlk} registered and active!"]
-        else:
-            return [f"{wlk} code issues encountered!"]
-
     @Interface.private_api()
     def walker_list(self, snt: Sentinel = None, detailed: bool = False):
         """
@@ -96,7 +54,7 @@ class WalkerApi:
         """
         Creates new instance of walker and returns new walker object
         """
-        wlk = snt.run_architype(name=name, kind="walker", caller=self)
+        wlk = snt.run_architype(name=name, kind="walker", caller=self, is_async=False)
         if wlk:
             if self.spawned_walker_ids.has_obj_by_name(name):
                 self.spawned_walker_ids.destroy_obj_by_name(name)
@@ -211,7 +169,7 @@ class WalkerApi:
         _req_ctx: dict = {},
         snt: Sentinel = None,
         profiling: bool = False,
-        is_async: bool = False,
+        is_async: bool = None,
     ):
         """
         Creates walker instance, primes walker on node, executes walker,
@@ -219,8 +177,9 @@ class WalkerApi:
         """
         wlk = self.yielded_walkers_ids.get_obj_by_name(name, silent=True)
         if wlk is None:
-            wlk = snt.run_architype(name=name, kind="walker", caller=self)
-            wlk._async = is_async
+            wlk = snt.run_architype(
+                name=name, kind="walker", caller=self, is_async=is_async
+            )
         if wlk is None:
             return self.bad_walk_response([f"Walker {name} not found!"])
         res = self.walker_execute(
