@@ -51,8 +51,10 @@ class Interp(MachineState):
         var_val = None  # jac's null
         if len(kid) > 1:
             var_val = self.run_expression(kid[2]).value
+        if isinstance(obj, dict):
+            obj[var_name] = var_val
         # Runs only once for walkers
-        if var_name not in obj.context.keys() or obj.j_type != "walker":
+        elif var_name not in obj.context.keys() or obj.j_type != "walker":
             JacValue(self, ctx=obj, name=var_name, value=var_val).write(
                 kid[0], force=True
             )
@@ -100,7 +102,7 @@ class Interp(MachineState):
                 self._jac_scope.add_action(act)
                 break
             else:
-                self.check_builtin_action(action_name, jac_ast)
+                # self.check_builtin_action(action_name, jac_ast)
                 act = Action(
                     m_id=self._m_id,
                     h=self._h,
@@ -427,38 +429,42 @@ class Interp(MachineState):
         """
         expression: connect (assignment | copy_assign | inc_assign)?;
         """
+        try:
 
-        def check_can_write(val):
-            if val.ctx is None:
-                self.rt_error("Cannot assign to this experssion", kid[0])
-                return False
-            return True
+            def check_can_write(val):
+                if val.ctx is None:
+                    self.rt_error("Cannot assign to this expression", kid[0])
+                    return False
+                return True
 
-        kid = self.set_cur_ast(jac_ast)
-        if len(kid) == 1:
-            return self.run_connect(kid[0])
-        else:
-            if kid[1].name == "assignment":
-                self._assign_mode = True
-                dest = self.run_connect(kid[0])
-                self._assign_mode = False
-                if not check_can_write(dest):
-                    return dest
-                return self.run_assignment(kid[1], dest=dest)
-            elif kid[1].name == "copy_assign":
-                self._assign_mode = True
-                dest = self.run_connect(kid[0])
-                self._assign_mode = False
-                if not check_can_write(dest):
-                    return dest
-                return self.run_copy_assign(kid[1], dest=dest)
-            elif kid[1].name == "inc_assign":
-                self._assign_mode = True
-                dest = self.run_connect(kid[0])
-                self._assign_mode = False
-                if not check_can_write(dest):
-                    return dest
-                return self.run_inc_assign(kid[1], dest=dest)
+            kid = self.set_cur_ast(jac_ast)
+
+            if len(kid) == 1:
+                return self.run_rule(kid[0])
+            else:
+                if kid[1].name == "assignment":
+                    self._assign_mode = True
+                    dest = self.run_rule(kid[0])
+                    self._assign_mode = False
+                    if not check_can_write(dest):
+                        return dest
+                    return self.run_assignment(kid[1], dest=dest)
+                elif kid[1].name == "copy_assign":
+                    self._assign_mode = True
+                    dest = self.run_rule(kid[0])
+                    self._assign_mode = False
+                    if not check_can_write(dest):
+                        return dest
+                    return self.run_copy_assign(kid[1], dest=dest)
+                elif kid[1].name == "inc_assign":
+                    self._assign_mode = True
+                    dest = self.run_rule(kid[0])
+                    self._assign_mode = False
+                    if not check_can_write(dest):
+                        return dest
+                    return self.run_inc_assign(kid[1], dest=dest)
+        except Exception as e:
+            self.jac_try_exception(e, jac_ast)
 
     def run_assignment(self, jac_ast, dest):
         """
@@ -511,56 +517,53 @@ class Interp(MachineState):
         """
         connect: logical ( (NOT)? edge_ref expression)?;
         """
-        try:
-            kid = self.set_cur_ast(jac_ast)
-            if len(kid) < 2:
-                return self.run_logical(kid[0])
-            bret = self.run_logical(kid[0])
-            base = bret.value
-            tret = self.run_expression(kid[-1])
-            target = tret.value
-            self.rt_check_type(base, [Node, JacSet], kid[0])
-            self.rt_check_type(target, [Node, JacSet], kid[-1])
-            if isinstance(base, Node):
-                base = JacSet(in_list=[base])
-            if isinstance(target, Node):
-                target = JacSet(in_list=[target])
-            if kid[1].name == "NOT":
-                for i in target.obj_list():
-                    for j in base.obj_list():
-                        j.detach_edges(i, self.run_edge_ref(kid[2]).obj_list())
-                return bret
-            else:
-                direction = kid[1].kid[0].name
-                for i in target.obj_list():
-                    for j in base.obj_list():
-                        use_edge = self.run_edge_ref(kid[1], is_spawn=True)
-                        self.rt_check_type(i, Node, kid[-1])
-                        self.rt_check_type(j, Node, kid[-1])
-                        if direction == "edge_from":
-                            j.attach_inbound(i, [use_edge])
-                        elif direction == "edge_to":
-                            j.attach_outbound(i, [use_edge])
-                        else:
-                            j.attach_bidirected(i, [use_edge])
+        kid = self.set_cur_ast(jac_ast)
+        if len(kid) < 2:
+            return self.run_rule(kid[0])
+        bret = self.run_rule(kid[0])
+        base = bret.value
+        tret = self.run_expression(kid[-1])
+        target = tret.value
+        self.rt_check_type(base, [Node, JacSet], kid[0])
+        self.rt_check_type(target, [Node, JacSet], kid[-1])
+        if isinstance(base, Node):
+            base = JacSet(in_list=[base])
+        if isinstance(target, Node):
+            target = JacSet(in_list=[target])
+        if kid[1].name == "NOT":
+            for i in target.obj_list():
+                for j in base.obj_list():
+                    j.detach_edges(i, self.run_edge_ref(kid[2]).obj_list())
             return bret
-        except Exception as e:
-            self.jac_try_exception(e, jac_ast)
+        else:
+            direction = kid[1].kid[0].name
+            for i in target.obj_list():
+                for j in base.obj_list():
+                    use_edge = self.run_edge_ref(kid[1], is_spawn=True)
+                    self.rt_check_type(i, Node, kid[-1])
+                    self.rt_check_type(j, Node, kid[-1])
+                    if direction == "edge_from":
+                        j.attach_inbound(i, [use_edge])
+                    elif direction == "edge_to":
+                        j.attach_outbound(i, [use_edge])
+                    else:
+                        j.attach_bidirected(i, [use_edge])
+        return bret
 
     def run_logical(self, jac_ast):
         """
         logical: compare ((KW_AND | KW_OR) compare)*;
         """
         kid = self.set_cur_ast(jac_ast)
-        result = self.run_compare(kid[0])
+        result = self.run_rule(kid[0])
         kid = kid[1:]
         while kid:
             if kid[0].name == "KW_AND":
                 if result.value:
-                    result.value = result.value and self.run_compare(kid[1]).value
+                    result.value = result.value and self.run_rule(kid[1]).value
             elif kid[0].name == "KW_OR":
                 if not result.value:
-                    result.value = result.value or self.run_compare(kid[1]).value
+                    result.value = result.value or self.run_rule(kid[1]).value
             kid = kid[2:]
             if not kid:
                 break
@@ -572,12 +575,12 @@ class Interp(MachineState):
         """
         kid = self.set_cur_ast(jac_ast)
         if kid[0].name == "NOT":
-            return JacValue(self, value=not self.run_compare(kid[1]).value)
+            return JacValue(self, value=not self.run_rule(kid[1]).value)
         else:
-            result = self.run_arithmetic(kid[0])
+            result = self.run_rule(kid[0])
             kid = kid[1:]
             while kid:
-                other_res = self.run_arithmetic(kid[1])
+                other_res = self.run_rule(kid[1])
                 result = self.run_cmp_op(kid[0], result, other_res)
                 kid = kid[2:]
                 if not kid:
@@ -611,10 +614,10 @@ class Interp(MachineState):
         arithmetic: term ((PLUS | MINUS) term)*;
         """
         kid = self.set_cur_ast(jac_ast)
-        result = self.run_term(kid[0])
+        result = self.run_rule(kid[0])
         kid = kid[1:]
         while kid:
-            other_res = self.run_term(kid[1])
+            other_res = self.run_rule(kid[1])
             if kid[0].name == "PLUS":
                 result.value = result.value + other_res.value
             elif kid[0].name == "MINUS":
@@ -629,10 +632,10 @@ class Interp(MachineState):
         term: factor ((STAR_MUL | DIV | MOD) factor)*;
         """
         kid = self.set_cur_ast(jac_ast)
-        result = self.run_factor(kid[0])
+        result = self.run_rule(kid[0])
         kid = kid[1:]
         while kid:
-            other_res = self.run_factor(kid[1])
+            other_res = self.run_rule(kid[1])
             if kid[0].name == "STAR_MUL":
                 result.value = result.value * other_res.value
             elif kid[0].name == "DIV":
@@ -649,10 +652,10 @@ class Interp(MachineState):
         factor: (PLUS | MINUS) factor | power;
         """
         kid = self.set_cur_ast(jac_ast)
-        if kid[0].name == "power":
-            return self.run_power(kid[0])
+        if len(kid) < 2:
+            return self.run_rule(kid[0])
         else:
-            result = self.run_factor(kid[1])
+            result = self.run_rule(kid[1])
             if kid[0].name == "MINUS":
                 result.value = -(result.value)
             return result
@@ -662,13 +665,13 @@ class Interp(MachineState):
         power: atom (POW factor)*;
         """
         kid = self.set_cur_ast(jac_ast)
-        result = self.run_atom(kid[0])
+        result = self.run_rule(kid[0])
         kid = kid[1:]
         if len(kid) < 1:
             return result
         elif kid[0].name == "POW":
             while kid:
-                result.value = result.value ** self.run_factor(kid[1]).value
+                result.value = result.value ** self.run_rule(kid[1]).value
                 kid = kid[2:]
                 if not kid:
                     break
@@ -716,6 +719,7 @@ class Interp(MachineState):
             | NAME
             | global_ref
             | node_edge_ref
+            | type_ref spawn_ctx?
             | list_val
             | dict_val
             | LPAREN expression RPAREN
@@ -744,12 +748,13 @@ class Interp(MachineState):
                 val = self._jac_scope.get_live_var(name, create_mode=self._assign_mode)
                 if val is None:
                     self.rt_error(f"Variable not defined - {name}", kid[0])
-                    return JacValue(
-                        self,
-                    )
+                    return JacValue(self)
                 return val
-            elif kid[0].name == "global_ref":
-                return self.run_global_ref(kid[0])
+            elif kid[0].name == "type_ref":
+                ret = self.run_type_ref(kid[0])
+                if kid[-1].name == "spawn_ctx":
+                    self.run_spawn_ctx(kid[-1], ret.value)
+                return ret
             elif kid[0].name == "LPAREN":
                 return self.run_expression(kid[1])
             elif kid[0].name == "ability_op":
@@ -1284,6 +1289,14 @@ class Interp(MachineState):
         )
         return gph
 
+    def run_type_ref(self, jac_ast):
+        """
+        graph_ref: KW_GRAPH DBL_COLON NAME;
+        """
+        kid = self.set_cur_ast(jac_ast)
+        obj = self.parent().run_architype(kid[2].token_text(), kind="type", caller=self)
+        return JacValue(self, value=obj)
+
     def run_edge_ref(self, jac_ast, is_spawn=False):
         """
         edge_ref: edge_to | edge_from | edge_any;
@@ -1617,6 +1630,9 @@ class Interp(MachineState):
         kid = self.set_cur_ast(jac_ast)
         name = kid[0].token_text()
         result = self.run_expression(kid[-1]).value
+        if isinstance(obj, dict):
+            obj[name] = result
+            return
         dest = JacValue(self, ctx=obj, name=name, value=result)
         if obj.j_type == "walker":
             dest.write(kid[0], force=True)
