@@ -1,4 +1,5 @@
 from jaseci.utils.test_core import CoreTest
+import uuid
 
 
 class StackTests(CoreTest):
@@ -19,3 +20,14 @@ class StackTests(CoreTest):
         self.mast._h.commit()
         self.call(self.mast, ["walker_run", {"name": "get_gen_day"}])
         self.assertEqual(len(self.mast._h.save_obj_list), 0)
+
+    def test_walker_context_auto_refresh(self):
+        ret = self.call(
+            self.mast,
+            ["sentinel_register", {"code": self.load_jac("ll.jac")}],
+        )
+        ret = self.call(self.mast, ["walker_run", {"name": "print_life_note"}])
+        life_node = self.mast._h.get_obj(self.mast._m_id, uuid.UUID(ret["final_node"]))
+        life_node.context.pop("note")
+        ret = self.call(self.mast, ["walker_run", {"name": "print_life_note"}])
+        self.assertTrue(ret["success"])
